==> v2.4.1.tar.gz: kratos/.github/ISSUE_TEMPLATE/feature-request.md <==
---
name: "\U0001F4A1 Feature Request"
about: For ideas or feature requests, start a new discussion.
title: "[Feature]"
labels: feature
assignees: ''
---

Please see the FAQ in our main README.md before submitting your issue.

<!--
In order to accurately distinguish that the needs put forward by users are the needs of most users and reasonable needs, solicit community opinions through the process, and the features adopted by the community will be realized as new functions.

In order to make the proposal process as simple as possible, the process includes three stages: feature request - > proposal - > pull-request, where feature, proposal is issue and pull-request is the specific function implementation.

### Feature-request

In order to help the community correctly understand the requirements of the feature, the feature request issue needs to describe the functional requirements and relevant references or documents in detail. And the feature request issue can contain the basic description of the function, which can be used as a reference for the function implementation in the proposal.

### Proposal

Proposal contains the basic implementation methods of functions, such as interface definition, general usage of functions, etc.

### Pull-request

After the function is realized, a merge request will be initiated to associate the proposal issue with the function issue. After the merger is completed, all questions will be closed and the process will end.

### Decision process

When more than five maintainer members agree to implement the feature, a proposal issue will be created for detailed design. The status of the proposal is divided into: under discussion, finalized and abandoned. After reaching the final status, start specific implementation (PR can also be implemented synchronously during the discussion)

### Final decision maker mechanism

If the maintainer team members have major differences on a requirement, the final decision is made by @Terry Mao.
-->

### What problem is the feature used to solve?
<!--
example:
    We hope to add event interface to Kratos framework to access middleware such as Kafka and rabbitmq
-->

### Requirements description of the feature
<!--
example:
    The event interface should be added to Kratos. The interface should contain subscribers and publishers, and the message body should contain key value heade
-->
### References
<!--
example:
    - [nats](http://xxxxx)
    - [kafka](http://xxxxx)
    - [rabbitmq](http://xxxxx)
-->

==> v2.6.1.tar.gz: kratos/.github/ISSUE_TEMPLATE/feature-request.md <==
---
name: "\U0001F4A1 Feature Request"
about: For ideas or feature requests, start a new discussion.
title: "[Feature]"
labels: feature
assignees: ''
---

Please see the FAQ in our main README.md before submitting your issue.

<!--
In order to accurately distinguish that the needs put forward by users are the needs of most users and reasonable needs, solicit community opinions through the process, and the features adopted by the community will be realized as new functions.

In order to make the proposal process as simple as possible, the process includes three stages: feature request - > proposal - > pull-request, where feature, proposal is issue and pull-request is the specific function implementation.

### Feature-request

In order to help the community correctly understand the requirements of the feature, the feature request issue needs to describe the functional requirements and relevant references or documents in detail. And the feature request issue can contain the basic description of the function, which can be used as a reference for the function implementation in the proposal.

### Proposal

Proposal contains the basic implementation methods of functions, such as interface definition, general usage of functions, etc.

### Pull-request

After the function is realized, a merge request will be initiated to associate the proposal issue with the function issue. After the merger is completed, all questions will be closed and the process will end.

### Decision process

When more than five maintainer members agree to implement the feature, a proposal issue will be created for detailed design. The status of the proposal is divided into: under discussion, finalized and abandoned. After reaching the final status, start specific implementation (PR can also be implemented synchronously during the discussion)

### Final decision maker mechanism

If the maintainer team members have major differences on a requirement, the final decision is made by @Terry Mao.
-->

### What problem is the feature used to solve?
<!--
example:
    We hope to add event interface to Kratos framework to access middleware such as Kafka and rabbitmq
-->

### Requirements description of the feature
<!--
example:
    The event interface should be added to Kratos. The interface should contain subscribers and publishers, and the message body should contain key value head
-->
### References
<!--
example:
    - [nats](http://xxxxx)
    - [kafka](http://xxxxx)
    - [rabbitmq](http://xxxxx)
-->
